@@ -39,9 +39,9 @@ gdImageStringFT (gdImage * im, int *brect, int fg, char *fontlist,
 #else
 
 #include "gdcache.h"
-#include "freetype/freetype.h"
-#include "freetype/ftglyph.h"
-
+#include <ft2build.h>
+#include FT_FREETYPE_H
+#include FT_GLYPH_H
 /* number of fonts cached before least recently used is replaced */
 #define FONTCACHESIZE 6
 
